@@ -173,18 +173,18 @@ static int upower_read_work(int battery, apm_info *info)
 		goto fail_close0;
 	}
 	else if (cv != sizeof(*info)) {
-		fprintf(stderr, "recv: unexpected size %d", cv);
+		fprintf(stderr, "recv: unexpected size %zd", cv);
 		goto fail_close0;
 	}
 
 	close(sp[0]);
 	return 0;
 
-	fail_close:
+fail_close:
 	close(sp[1]);
-	fail_close0:
+fail_close0:
 	close(sp[0]);
-	fail:
+fail:
 	return -1;
 }
 
